@@ -323,6 +323,7 @@ PropertyValue = Union[
     CameraActivitySettings,
     list[DetectionZone],
     list[CameraInput],
+    CameraFrameWorkerSettings,
 ]
 
 
@@ -684,6 +685,7 @@ class CameraSource(Protocol):
 
 
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
+ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
 
 
 class ImageFormat(TypedDict):
@@ -708,9 +710,6 @@ class ImageOptions(TypedDict):
     resize: NotRequired[ImageResize]
 
 
-ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
-
-
 class IceServer(TypedDict):
     urls: list[str]
     username: NotRequired[str]
@@ -824,7 +823,6 @@ class CameraDevice(Protocol):
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
     async def get_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
-    async def get_prebuffered_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
 
@@ -925,48 +923,6 @@ class CameraDevice(Protocol):
         self, state_name: StateNames
     ) -> Observable[CameraStateChangedObject[StateValue]]: ...
 
-    @overload
-    def on_property_change(
-        self, property_name: Literal["name"]
-    ) -> Observable[CameraPropertyObservableObject[str]]: ...
-    @overload
-    def on_property_change(
-        self,
-        property_name: Literal[
-            "disabled",
-            "isCloud",
-            "hasLight",
-            "hasSiren",
-            "hasBinarySensor",
-            "hasBattery",
-            "hasAudioDetector",
-            "hasMotionDetector",
-            "hasObjectDetector",
-            "hasPrebuffer",
-            "hasIntercom",
-            "hasPtz",
-        ],
-    ) -> Observable[CameraPropertyObservableObject[bool]]: ...
-    @overload
-    def on_property_change(
-        self, property_name: Literal["info"]
-    ) -> Observable[CameraPropertyObservableObject[CameraInformation]]: ...
-    @overload
-    def on_property_change(
-        self, property_name: Literal["type"]
-    ) -> Observable[CameraPropertyObservableObject[CameraType]]: ...
-    @overload
-    def on_property_change(
-        self, property_name: Literal["activityZones"]
-    ) -> Observable[CameraPropertyObservableObject[list[DetectionZone]]]: ...
-    @overload
-    def on_property_change(
-        self, property_name: Literal["activitySettings"]
-    ) -> Observable[CameraPropertyObservableObject[CameraActivitySettings]]: ...
-    @overload
-    def on_property_change(
-        self, property_name: Literal["sources"]
-    ) -> Observable[CameraPropertyObservableObject[list[CameraInput]]]: ...
     def on_property_change(  # type: ignore
         self, property_name: CameraPublicProperties
     ) -> Observable[CameraPropertyObservableObject[PropertyValue]]: ...
@@ -1014,10 +970,6 @@ CameraDeselectedCallback = Union[
     Callable[[str, CameraExtension], None],
     Callable[[str, CameraExtension], Coroutine[None, None, None]],
 ]
-CameraUpdatedCallback = Union[
-    Callable[[str, CameraExtension], None],
-    Callable[[str, CameraExtension], Coroutine[None, None, None]],
-]
 
 
 # abstract
